 class: CommandLineTool
 cwlVersion: v1.0
 doc: |
    DESCRIPTION
        This program converts the SAM/BAM file generated by user's aligner into
        a BAM file which RSEM can process. However, users should make sure their
        aligners use 'reference_name.idx.fa' generated by
        'rsem-prepare-reference' as their references and output header sections.
        This program will create a temporary directory called
        'output_file_name.bam.temp' to store the intermediate files. The
        directory will be deleted automatically after the conversion. After the
        conversion, this program will call 'rsem-sam-validator' to validate the
        resulting BAM file.
        Note: You do not need to run this script if `rsem-sam-validator' reports
        that your SAM/BAM file is valid.
        Note: This program does not check the correctness of input file. You
        should make sure the input is a valid SAM/BAM format file.
    EXAMPLES
        Suppose input is set to 'input.sam' and output file name is "output"
         convert-sam-for-rsem input.sam output
        We will get a file called 'output.bam' as output.
 requirements:
    InlineJavascriptRequirement: {}
    ShellCommandRequirement: {}
 hints:
    DockerRequirement:
      dockerPull: dukegcb/rsem:1.2.21
 inputs:
    bam_or_sam:
      type: string
      default: bam
    output_suffix:
      type: string
      default: .converted_for_rsem
    input_file:
      type: File
      inputBinding:
        position: 2
      doc: |
        The SAM or BAM file generated by user's aligner. We require this
        file contains the header section. If input is a SAM file, it must
        end with suffix 'sam' (case insensitive). If input is a BAM file, it
        must end with suffix 'bam' (case insensitive).
 outputs:
    output_file:
      type: File
      outputBinding:
        glob: $(inputs.input_file.path.replace(/^.*[\\\/]/, '').replace(/\.[^/.]+$/, "") + inputs.output_suffix + "." + inputs.bam_or_sam)
 baseCommand: convert-sam-for-rsem
 arguments:
  - valueFrom: $("--temporary-directory " + runtime.tmpdir)
    shellQuote: false
    position: 1
  - valueFrom: $(inputs.input_file.path.replace(/^.*[\\\/]/, '').replace(/\.[^/.]+$/, "") + inputs.output_suffix)
    position: 3
